import time
from dask.distributed import Client, LocalCluster
import sys

print(sys.argv)
worker = int(sys.argv[1])

if __name__ == '__main__':
    cluster = LocalCluster(
        n_workers = worker,
        scheduler_port = 8786,
        host = '0.0.0.0',
        dashboard_address = '0.0.0.0:8787',
    )

    while True:
        time.sleep(600)



import socket
import requests


def port_open(ip, port):
    s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
    try:
        s.connect((ip, int(port)))
        s.shutdown(2)
        return True
    except:
        return False


def post_slack(
    slack_msg: str,
    webhook: str = None,
    username: str = 'Dask Alert',
    icon_url: str = 'https://avatars3.githubusercontent.com/u/17131925?s=400&v=4',
    **kwargs
):
    payload = {'text': slack_msg, 'username': username, 'icon_url': icon_url}
    return requests.post(webhook, json = payload).status_code


def wait_for_operation(compute, project, zone, operation):
    while True:
        result = (
            compute.zoneOperations()
            .get(project = project, zone = zone, operation = operation)
            .execute()
        )

        if result['status'] == 'DONE':
            if 'error' in result:
                raise Exception(result['error'])
            return result

        time.sleep(1)



import googleapiclient.discovery
from dask.distributed import Client
from datetime import datetime, timedelta
import time
import sys
import requests
import cloudpickle


print(sys.argv)
name = sys.argv[1]
project = sys.argv[2]
zone = sys.argv[3]
expired = int(sys.argv[4])


with open('post.pkl', 'rb') as fopen:
    post_message = cloudpickle.load(fopen)


while True:
    try:
        client = Client('dask:8786')
        break
    except:
        time.sleep(5)

now = datetime.now()
while True:
    workers = client.scheduler_info()['workers']
    if any([v['metrics']['executing'] != 0 for k, v in workers.items()]):
        now = datetime.now()

    if (datetime.now() - now).seconds > expired:
        slack_msg = """
            Gracefully deleted Dask cluster. 
            *Time shutdown*: {exec_date}
            *Dask cluster name*: {dask_name}
            """.format(
            exec_date = str(datetime.now()), dask_name = name
        )
        post_message(slack_msg)
        compute = googleapiclient.discovery.build('compute', 'v1')
        compute.instances().delete(
            project = project, zone = zone, instance = name
        ).execute()
        break
